/**
  @file main.c
  @brief
  Empty source file for a new FT90x project.

 */
/*
 * ============================================================================
 * History
 * =======
 * 20 Jan 2016 : Created
 *
 * (C) Copyright 2014-2016, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef LWIPOPTS_H_
#define LWIPOPTS_H_

/* NO_SYS
 * Do not use Operating System (RTOS) style primitives and implement stack
 * as a single threaded application.
 */
#define NO_SYS                     1
/* NO_SYS_NO_TIMERS
 * Still use timers provided by interrupt sources in the application.
 */
#define NO_SYS_NO_TIMERS           0

/* SYS_LIGHTWEIGHT_PROT
 * define SYS_LIGHTWEIGHT_PROT in lwipopts.h if you want inter-task protection
 * for certain critical regions during buffer allocation, deallocation and memory
 * allocation and deallocation.
 */
#define SYS_LIGHTWEIGHT_PROT    (NO_SYS==0)

/* LWIP_SOCKET/LWIP_NETCONN
 * Disable socket interface and network sequential API as NO_SYS is defined.
 */
#define LWIP_SOCKET               (NO_SYS==0)
#define LWIP_NETCONN              (NO_SYS==0)

/* LWIP_IGMP
 * Disable Internet Group Management Protocol
 * There's no need for IP multicast support in this application.
 */
#define LWIP_IGMP                  1

/* LWIP_ICMP
 * Enable Internet Control Message Protocol
 * Allow support for ICMP which includes ping.
 */
#define LWIP_ICMP                  1

/* LWIP_SNMP
 * Disable Simple Network Management Protocol
 * There's no need for SNMP support in this application.
 */
#define LWIP_SNMP                  0

/* LWIP_DNS
 * Disable lwIP DNS module,
 */
#define LWIP_DNS                   0

/* LWIP_RAW
 * Disable raw access so application has to go through UDP or TCP.
 */
#define LWIP_RAW                   0

/* LWIP_HAVE_LOOPIF
 * Disable loopback interface.
 */
#define LWIP_HAVE_LOOPIF           0
#define LWIP_NETIF_LOOPBACK        0
#define LWIP_LOOPBACK_MAX_PBUFS    5

#define TCP_LISTEN_BACKLOG         0

#define LWIP_COMPAT_SOCKETS        0
#define LWIP_SO_SNDTIMEO           1
#define LWIP_SO_RCVTIMEO           1
#define LWIP_SO_RCVBUF             0

#define LWIP_TCPIP_CORE_LOCKING    0

/* LWIP_NETIF_LINK_CALLBACK
 * Do not require or use a callback for link status change.
 */
#define LWIP_NETIF_LINK_CALLBACK   0

/* LWIP_NETIF_STATUS_CALLBACK
 * Do provide a callback for connection status change.
 */
#define LWIP_NETIF_STATUS_CALLBACK 1

#define LWIP_DEBUG
#define LWIP_NOASSERT

#ifdef LWIP_DEBUG
//#define LWIP_DBG_TRACE

#define LWIP_DBG_MIN_LEVEL         0
#define SYS_DEBUG                  LWIP_DBG_OFF
#define TIMERS_DEBUG               LWIP_DBG_OFF
#define PPP_DEBUG                  LWIP_DBG_OFF
#define MEM_DEBUG                  LWIP_DBG_OFF
#define MEMP_DEBUG                 LWIP_DBG_OFF
#define PBUF_DEBUG                 LWIP_DBG_OFF
#define API_LIB_DEBUG              LWIP_DBG_OFF
#define API_MSG_DEBUG              LWIP_DBG_OFF
#define TCPIP_DEBUG                LWIP_DBG_OFF
#define NETIF_DEBUG                LWIP_DBG_OFF
#define SOCKETS_DEBUG              LWIP_DBG_OFF
#define ETHARP_DEBUG               LWIP_DBG_OFF
#define DNS_DEBUG                  LWIP_DBG_OFF
#define AUTOIP_DEBUG               LWIP_DBG_OFF
#define DHCP_DEBUG                 LWIP_DBG_OFF
#define RAW_DEBUG                  LWIP_DBG_OFF
#define IP_DEBUG                   LWIP_DBG_OFF
#define IP_REASS_DEBUG             LWIP_DBG_OFF
#define ICMP_DEBUG                 LWIP_DBG_OFF
#define IGMP_DEBUG                 LWIP_DBG_OFF
#define UDP_DEBUG                  LWIP_DBG_OFF
#define TCP_DEBUG                  LWIP_DBG_OFF
#define TCP_INPUT_DEBUG            LWIP_DBG_OFF
#define TCP_OUTPUT_DEBUG           LWIP_DBG_OFF
#define TCP_RTO_DEBUG              LWIP_DBG_OFF
#define TCP_CWND_DEBUG             LWIP_DBG_OFF
#define TCP_WND_DEBUG              LWIP_DBG_OFF
#define TCP_FR_DEBUG               LWIP_DBG_OFF
#define TCP_QLEN_DEBUG             LWIP_DBG_OFF
#define TCP_RST_DEBUG              LWIP_DBG_OFF
#define RTP_DEBUG                  LWIP_DBG_OFF

#endif /* LWIP_DEBUG */

#define LWIP_DBG_TYPES_ON         (LWIP_DBG_ON|LWIP_DBG_TRACE|LWIP_DBG_STATE|LWIP_DBG_FRESH|LWIP_DBG_HALT)


/* ---------- Memory options ---------- */

#define MEM_LIBC_MALLOC             1
#define MEMP_MEM_MALLOC             1

#define MEMP_OVERFLOW_CHECK             1

/* MEM_ALIGNMENT: should be set to the alignment of the CPU for which
   lwIP is compiled. 4 byte alignment -> define MEM_ALIGNMENT to 4, 2
   byte alignment -> define MEM_ALIGNMENT to 2. */
/* MSVC port: intel processors don't need 4-byte alignment,
   but are faster that way! */
#define MEM_ALIGNMENT 4

/** ETH_PAD_SIZE: number of bytes added before the ethernet header to ensure
 * alignment of payload after that header. Since the header is 14 bytes long,
 * without this padding e.g. addresses in the IP header will not be aligned
 * on a 32-bit boundary, so setting this to 2 can speed up 32-bit-platforms.
 */
#define ETH_PAD_SIZE 2

/* MEM_SIZE: the size of the heap memory. If the application will send
a lot of data that needs to be copied, this should be set high. */
#define MEM_SIZE               (10 * 1024)

/* MEMP_NUM_PBUF: the number of memp struct pbufs. If the application
   sends a lot of data out of ROM (or other static memory), this
   should be set high. */
#define MEMP_NUM_PBUF           8
/* MEMP_NUM_RAW_PCB: the number of RAW connection protocol control blocks. One
   per active RAW "connection". */
#define MEMP_NUM_RAW_PCB        0
/* MEMP_NUM_UDP_PCB: the number of UDP protocol control blocks. One
   per active UDP "connection". */
#define MEMP_NUM_UDP_PCB        4
/* MEMP_NUM_TCP_PCB: the number of simultaneously active TCP
   connections. */
#define MEMP_NUM_TCP_PCB        4
/* MEMP_NUM_TCP_PCB_LISTEN: the number of listening TCP
   connections. */
#define MEMP_NUM_TCP_PCB_LISTEN 4
/* MEMP_NUM_TCP_SEG: the number of simultaneously queued TCP
   segments. */
#define MEMP_NUM_TCP_SEG        4
/* MEMP_NUM_SYS_TIMEOUT: the number of simultaneously active
   timeouts. */
#define MEMP_NUM_SYS_TIMEOUT    9

/* The following four are used only with the sequential API and can be
   set to 0 if the application only will use the raw API. */
/* MEMP_NUM_NETBUF: the number of struct netbufs. */
#define MEMP_NUM_NETBUF         0
/* MEMP_NUM_NETCONN: the number of struct netconns. */
#define MEMP_NUM_NETCONN        0
/* MEMP_NUM_TCPIP_MSG_*: the number of struct tcpip_msg, which is used
   for sequential API communication and incoming packets. Used in
   src/api/tcpip.c. */
#define MEMP_NUM_TCPIP_MSG_API   0
#define MEMP_NUM_TCPIP_MSG_INPKT 0


/* ---------- Pbuf options ---------- */
/* PBUF_POOL_SIZE: the number of buffers in the pbuf pool. */
#define PBUF_POOL_SIZE          8

/* PBUF_LINK_HLEN: the number of bytes that should be allocated for a
   link level header. */
#define PBUF_LINK_HLEN          20

/* ---------- TCP options ---------- */
#define LWIP_TCP                1
#define TCP_TTL                 255

/* Controls if TCP should queue segments that arrive out of
   order. Define to 0 if your device is low on memory. */
#define TCP_QUEUE_OOSEQ         0

/* TCP Maximum segment size. */
#define TCP_MSS                 1024

/* TCP receive window. */
#define TCP_WND                 2048
#define TCP_SND_BUF             (4 * TCP_MSS)

/* Maximum number of retransmissions of data segments. */
#define TCP_MAXRTX              12

/* Maximum number of retransmissions of SYN segments. */
#define TCP_SYNMAXRTX           4

#define LWIP_TCP_KEEPALIVE 1


/* ---------- ARP options ---------- */
#define LWIP_ARP                1
#define ARP_TABLE_SIZE          10
#define ARP_QUEUEING            1

/* LWIP_BROADCAST_PING==1: respond to broadcast pings (default is unicast only) */
#define LWIP_BROADCAST_PING     1

/* LWIP_MULTICAST_PING==1: respond to multicast pings (default is unicast only) */
#define LWIP_MULTICAST_PING     0

/* ---------- IP options ---------- */
/* Define IP_FORWARD to 1 if you wish to have the ability to forward
   IP packets across network interfaces. If you are going to run lwIP
   on a device with only one network interface, define this to 0. */
#define IP_FORWARD              0

/* IP reassembly and segmentation.These are orthogonal even
 * if they both deal with IP fragments */
#define IP_REASSEMBLY           1
#define IP_REASS_MAX_PBUFS      10
#define MEMP_NUM_REASSDATA      10
#define IP_FRAG                 1

/* ---------- ICMP options ---------- */
#define ICMP_TTL                255

/* ---------- DHCP options ---------- */
/* Define LWIP_DHCP to 1 if you want DHCP configuration of
   interfaces. */
#define LWIP_DHCP               1

/* 1 if you want to want DHCP to wait for link to be up
   before starting. */
#define LWIP_DHCP_CHECK_LINK_UP 1
/* 1 if you want to do an ARP check on the offered address
   (recommended). */
#define DHCP_DOES_ARP_CHECK		1
/* 1 if you want to send a hostname to the DHCP server.
   (recommended). */
#define LWIP_NETIF_HOSTNAME     1

/* ---------- AUTOIP options ------- */
#define LWIP_AUTOIP             1
#define LWIP_DHCP_AUTOIP_COOP  (LWIP_DHCP && LWIP_AUTOIP)

/* ---------- UDP options ---------- */
#define LWIP_UDP                1
#define LWIP_UDPLITE            0
#define UDP_TTL                 255

/* ---------- Statistics options ---------- */

#define LWIP_STATS              1
#define LWIP_STATS_DISPLAY      1

#if LWIP_STATS
#define LINK_STATS              1
#define IP_STATS                0
#define ICMP_STATS              0
#define IGMP_STATS              0
#define IPFRAG_STATS            0
#define UDP_STATS               0
#define TCP_STATS               1
#define MEM_STATS               0
#define MEMP_STATS              0
#define PBUF_STATS              0
#define SYS_STATS               0
#endif /* LWIP_STATS */


/* ---------- PPP options ---------- */
#define PPP_SUPPORT             0      /* Set > 0 for PPP */

/* ---------- Checksum options ---------- */
/* CHECKSUM_GEN_IP==1: Generate checksums in software for outgoing IP packets. */
#define CHECKSUM_GEN_IP         1
/* CHECKSUM_GEN_UDP==1: Generate checksums in software for outgoing UDP packets. */
#define CHECKSUM_GEN_UDP        1
/* CHECKSUM_GEN_TCP==1: Generate checksums in software for outgoing TCP packets. */
#define CHECKSUM_GEN_TCP        1
/* CHECKSUM_GEN_ICMP==1: Generate checksums in software for outgoing ICMP packets. */
#define CHECKSUM_GEN_ICMP       1
/* CHECKSUM_CHECK_IP==1: Check checksums in software for incoming IP packets. */
#define CHECKSUM_CHECK_IP       1
/* CHECKSUM_CHECK_UDP==1: Check checksums in software for incoming UDP packets. */
#define CHECKSUM_CHECK_UDP      1
/* CHECKSUM_CHECK_TCP==1: Check checksums in software for incoming TCP packets. */
#define CHECKSUM_CHECK_TCP      1
/* LWIP_CHECKSUM_ON_COPY==1: Calculate checksum when copying data from
 * application buffers to pbufs. */
#define LWIP_CHECKSUM_ON_COPY   0

/* ---------- HTTPD options ---------- */
/* Support CGI scripts */
#define LWIP_HTTPD_CGI            1
/* Support SSI (Server-Side-Includes) */
#define LWIP_HTTPD_SSI            1

#endif /* LWIPOPTS_H_ */
